@@ -8,7 +8,7 @@ except ImportError:
     from importlib_metadata import metadata, version
     from importlib_resources import files
 
-from .excel_defination import ExcelDefination
+from .excel_definition import Exceldefinition
 from .excel_operation import (
     output_to_csv_file,
     output_to_excel_file,
@@ -28,7 +28,7 @@ from .story import (
 __version__ = version("sharry_jira_tool")
 
 __all__ = [
-    "ExcelDefination",
+    "Exceldefinition",
     "read_excel_file",
     "output_to_csv_file",
     "output_to_excel_file",
