@@ -268,4 +268,4 @@ def process_excel_file(
         output_file, stories, excel_definition, excel_columns, over_write
     )
 
-    print("%s has been saved.", output_file)
+    print(f"{output_file} has been saved.")
