@@ -6,9 +6,10 @@ from typing import Any
 
 from dateutil import parser
 
-from .excel_defination import ExcelDefination
+from .excel_definition import Exceldefinition
 from .milestone import *
 from .priority import *
+from .sprint_schedule import SprintScheduleStore
 
 __all__ = [
     "Story",
@@ -71,7 +72,7 @@ class Story(object):
             else:
                 setattr(self, column[1], None)
 
-    def __getitem__(self, property_name):
+    def __getitem__(self, property_name) -> "Milestone | Any":
         return getattr(self, property_name)
 
     def format_value(self, property_name: str) -> str:
@@ -109,6 +110,11 @@ class Story(object):
     def __setitem__(self, property_name, property_value):
         self.set_value(type(property_value), property_name, property_value)
 
+    def calc_sprint_schedule(self, sprint_schedule: SprintScheduleStore):
+        for _, column_name, column_type, _, _, _, _ in self.factory.columns:
+            if column_type is Milestone:
+                self[column_name].calc_priority(sprint_schedule)
+
     # Currently, comparing story only consider the Priority properties.
     def __lt__(self, __o: object) -> bool:
         return self.factory.compare_story(self, __o) < 0
@@ -243,12 +249,12 @@ class StoryFactory(object):
 
 
 def sort_stories_by_property_and_order(
-    stories: "list[Story]", excel_defination: ExcelDefination
+    stories: "list[Story]", excel_definition: Exceldefinition
 ):
     sort_rules = []
-    excel_defination_columns = excel_defination.get_columns()
+    excel_definition_columns = excel_definition.get_columns()
 
-    for _, column_name, _, require_sort, sort_order, _, _ in excel_defination_columns:
+    for _, column_name, _, require_sort, sort_order, _, _ in excel_definition_columns:
         if require_sort is True:
             sort_rules.append((column_name, sort_order))
 
@@ -263,10 +269,10 @@ def _internal_sort_stories_by_property_and_order(
 
 
 def sort_stories_by_raise_ranking(
-    stories: "list[Story]", excel_defination: ExcelDefination
+    stories: "list[Story]", excel_definition: Exceldefinition
 ) -> "list[Story]":
     sort_rules = []
-    excel_defination_columns = excel_defination.get_columns()
+    excel_definition_columns = excel_definition.get_columns()
 
     for (
         _,
@@ -276,7 +282,7 @@ def sort_stories_by_raise_ranking(
         _,
         _,
         ranking,
-    ) in excel_defination_columns:
+    ) in excel_definition_columns:
         if ranking > 0:
             sort_rules.append((column_name, ranking))
 
